'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.displayOrder = exports.transforms = undefined;
exports.richestMimetype = richestMimetype;

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _TextDisplay = require('./components/TextDisplay');

var _TextDisplay2 = _interopRequireDefault(_TextDisplay);

var _ImageDisplay = require('./components/ImageDisplay');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var transforms = exports.transforms = new _immutable2.default.Map({
  'text/plain': _TextDisplay2.default,
  'image/png': _ImageDisplay.PNGDisplay,
  'image/jpeg': _ImageDisplay.JPEGDisplay,
  'image/gif': _ImageDisplay.GIFDisplay
});

var displayOrder = exports.displayOrder = new _immutable2.default.List(['application/javascript', 'text/html', 'text/markdown', 'text/latex', 'image/svg+xml', 'image/gif', 'image/png', 'image/jpeg', 'application/pdf', 'text/plain']);

/**
 * Choose the richest mimetype available based on the displayOrder and transforms
 * @param  {Immutable.Map}   bundle - Map({mimetype1: data1, mimetype2: data2, ...})
 * @param  {Immutable.List}  ordered list of mimetypes - List(['text/html', 'text/plain'])
 * @param  {Immutable.Map}   mimetype -> React Component - Map({'text/plain': TextTransform})
 * @return {string}          Richest mimetype
 */
function richestMimetype(bundle) {
  var order = arguments.length <= 1 || arguments[1] === undefined ? displayOrder : arguments[1];
  var tf = arguments.length <= 2 || arguments[2] === undefined ? transforms : arguments[2];

  return bundle.keySeq()
  // we can only use those we have a transform for
  .filter(function (mimetype) {
    return tf.has(mimetype);
  })
  // the richest is based on the order in displayOrder
  .sortBy(function (mimetype) {
    return order.indexOf(mimetype);
  }).first();
}
//# sourceMappingURL=Transform.js.map